from django.urls import re_path, include
from django.contrib.auth.decorators import login_required

import query_designer.views as views

urlpatterns = [
    # api
    re_path('datasets/$', views.datasets),
    re_path('datasets/(?P<dataset_id>[\w-]+)/variables/$',
        views.dataset_variables),
    re_path('datasets/(?P<dataset_id>[\w-]+)/variables/(?P<variable_id>[\w-]+)/properties/$',
        views.dataset_variable_properties),
    re_path('datasets/(?P<dataset_id>[\w-]+)/variables/(?P<variable_id>[\w-]+)/count/$',
        views.count_variable_values),
    # url('list/$', views.queries),

    # execute
    re_path('execute/$', views.execute_query, name='execute-query'),
    re_path('execute/(?P<pk>\d+)/$', views.execute_query, name='execute-query'),

    re_path('simplified/config/$', views.get_config, name='config'),

    # load
    re_path('load/(?P<pk>\d+)/$', views.load_query, name='load-query'),

    # delete
    re_path('delete/(?P<pk>\d+)/$', views.delete_query, name='delete-query'),

    # save
    re_path('save/(?P<temp>\d+)/$', views.save_query, name='save-query'),
    re_path('save/(?P<pk>\d+)/(?P<temp>\d+)/$',
        views.save_query, name='save-query'),

    # get select variables
    re_path('get_query_variables/$', views.get_query_variables,
        name='get-query-variables'),

    # api

    re_path('api/get_query_info/(?P<query_id>\d+)/$',
        views.get_query_info, name='get_query_info'),
    re_path('api/list_user_queries/$',
        views.api_list_user_queries, name='list_user_queries'),
    re_path('api/delete_query/(?P<pk>\d+)/$',
        views.delete_query, name='delete_query'),
    re_path('api/execute/$', views.execute_query, name='execute-query'),
    re_path('api/execute/(?P<pk>\d+)/$', views.execute_query, name='execute-query'),
    re_path('api/get_query_statement/(?P<query_id>\d+)/$',
        views.get_query_statement, name='get_query_statement'),


    # basic page
    re_path('$', views.clean, name='clean'),


]
